# mexm-base
Materials Ex Machina base code

The Materials Ex Machina code is a refactor of the code base of pypospack, which was written the requirements for Eugene J. Ragasa's PhD requirements at the University of Florida.  The original code base was written primarily to deal with the problem of potential optimization.  The code base for Materials Ex Machina looks to use the same programming components for fast calculations using interatomic potentials, but also more expensive computational materials science simulations which requires management of simulations using MPI.

Deus Ex Machina. (1) a Latin phrase originally described an ancient plot device used in Greek and Roman theatre to resolve complicated or even hopeless situations in the plots of their plays. Literally means "god from the machine", (2) a person or thing that appears or is introduced suddenly and unexpectedly and provides a contrived solution to an insoluble difficulty.

Materials Ex Machina represents the current state of computational materials science in a variety of different ways.  Certain tools such as Density Functional Theory are being used as exhaustive search tools for finding new materials from techniques generally referred to as in silico high-throughput computing.  Computational searches for optimal alloys using tools such as AT-AT provide impetus for a computational driven approach to new materials design.

Computational material science is also a difficult field because much of the information to do high quality simulations simply does not exist, and approaches to creating high quality simulations is usually not documented in peer-reviewed journal articles, tutorials usually only cover trivial material problems, and reference textbooks concentrate on theory rather the ability to do useful simulations.

Environment variables which need to be set:

LAMMPS_SERIAL_BIN
LAMMPS_MPI_BIN
GULP_SERIAL_BIN
VASP_BIN
